@@ -5,7 +5,7 @@ MENUS = {
         {
             "name": _("Timetables"),
             "url": "#",
-            "icon": "school",
+            "svg_icon": "mdi:school-outline",
             "root": True,
             "validators": [
                 "menu_generator.validators.is_authenticated",
@@ -15,7 +15,7 @@ MENUS = {
                 {
                     "name": _("My timetable"),
                     "url": "my_timetable",
-                    "icon": "person",
+                    "svg_icon": "mdi:account-outline",
                     "validators": [
                         (
                             "aleksis.core.util.predicates.permission_validator",
@@ -26,7 +26,7 @@ MENUS = {
                 {
                     "name": _("All timetables"),
                     "url": "all_timetables",
-                    "icon": "grid_on",
+                    "svg_icon": "mdi:grid",
                     "validators": [
                         (
                             "aleksis.core.util.predicates.permission_validator",
@@ -37,7 +37,7 @@ MENUS = {
                 {
                     "name": _("Daily lessons"),
                     "url": "lessons_day",
-                    "icon": "calendar_today",
+                    "svg_icon": "mdi:calendar-outline",
                     "validators": [
                         (
                             "aleksis.core.util.predicates.permission_validator",
@@ -48,7 +48,7 @@ MENUS = {
                 {
                     "name": _("Substitutions"),
                     "url": "substitutions",
-                    "icon": "update",
+                    "svg_icon": "mdi:update",
                     "validators": [
                         (
                             "aleksis.core.util.predicates.permission_validator",
