@@ -415,6 +415,18 @@ class Lesson(ValidityRangeRelatedExtensibleModel, GroupPropertiesMixin, TeacherP
         """Get teachers relation."""
         return self.teachers
 
+    @property
+    def _equal_lessons(self):
+        """Get all lesson periods with equal lessons in the whole school term."""
+
+        qs = Lesson.objects.filter(
+            subject=self.subject,
+            validity__school_term=self.validity.school_term,
+        )
+        for group in self.groups.all():
+            qs = qs.filter(groups=group)
+        return qs
+
     def __str__(self):
         return f"{format_m2m(self.groups)}, {self.subject.short_name}, {format_m2m(self.teachers)}"
 
@@ -581,18 +593,10 @@ class LessonPeriod(WeekAnnotationMixin, TeacherPropertiesMixin, ExtensibleModel)
         return f"{self.period}, {self.lesson}"
 
     @property
-    def _equal_lessons(self):
+    def _equal_lesson_periods(self):
         """Get all lesson periods with equal lessons in the whole school term."""
 
-        qs = LessonPeriod.objects.filter(
-            lesson__subject=self.lesson.subject,
-            lesson__validity__school_term=self.lesson.validity.school_term,
-        )
-        for group in self.lesson.groups.all():
-            qs = qs.filter(lesson__groups=group)
-        for teacher in self.lesson.teachers.all():
-            qs = qs.filter(lesson__teachers=teacher)
-        return qs
+        return LessonPeriod.objects.filter(lesson__in=self.lesson._equal_lessons)
 
     @property
     def next(self) -> "LessonPeriod":
@@ -601,7 +605,7 @@ class LessonPeriod(WeekAnnotationMixin, TeacherPropertiesMixin, ExtensibleModel)
         .. warning::
             To use this property,  the provided lesson period must be annotated with a week.
         """
-        return self._equal_lessons.next_lesson(self)
+        return self._equal_lesson_periods.next_lesson(self)
 
     @property
     def prev(self) -> "LessonPeriod":
@@ -610,7 +614,7 @@ class LessonPeriod(WeekAnnotationMixin, TeacherPropertiesMixin, ExtensibleModel)
         .. warning::
             To use this property,  the provided lesson period must be annotated with a week.
         """
-        return self._equal_lessons.next_lesson(self, -1)
+        return self._equal_lesson_periods.next_lesson(self, -1)
 
     def is_replaced_by_event(
         self, events: Iterable[Event], groups: Optional[Iterable[Group]] = None
@@ -627,6 +631,10 @@ class LessonPeriod(WeekAnnotationMixin, TeacherPropertiesMixin, ExtensibleModel)
         else:
             groups_lesson_period = set(self.lesson.groups.all())
 
+            # The lesson period isn't replacable if the lesson has no groups at all
+            if not groups_lesson_period:
+                return False
+
             # This lesson period is replaced by an event ...
             # ... if all groups of this lesson period are a part of the event ...
             if groups_lesson_period.issubset(groups_of_event):
